@@ -29,6 +29,16 @@ class OSSUtils:
         bucket_name,
         use_vpc=False,
     ):
+        """
+        description:
+            初始化OSS工具类
+        parameters:
+            access_key_id(str): 阿里云访问密钥ID
+            access_key_secret(str): 阿里云访问密钥Secret
+            region_id(str): 阿里云区域ID
+            bucket_name(str): OSS存储桶名称
+            use_vpc(bool): 是否使用VPC内网端点，默认为False
+        """
         self.bucket_name = bucket_name
         if use_vpc:
             self.endpoint = f"https://oss-{region_id}-internal.aliyuncs.com"
